# coding=utf-8
"""conftest"""


import pytest

from genome import Genotype, SNP


@pytest.fixture()
def genotype():
    return Genotype('CC')


@pytest.fixture
def snp(genotype):
    return SNP(1, 762320, genotype)




# coding=utf-8
"""Genome"""
import os

from smart_open import open

from .genome import Genome
from .snp import SNP
from .genotype import Genotype


def load(filename, provider='23andme'):
    """

    Parameters
    ----------
    filename : str
        filepath to data source
    provider : str
        the data provider

    Returns
    -------
    genome : Genome
        Genome data
    """
    filepath = os.path.expanduser(filename)
    genome = Genome(name=filepath)
    if provider.lower() == '23andme':
        reader = ttandme_reader
    elif provider.lower() == 'ancestry':
        reader = ancestry_reader
    else:
        raise TypeError('We don\'t support provider: {}'.format(provider))

    with open(filepath, 'r') as fin:
        while True:
            line = fin.readline()
            if not line.startswith('#'):
                break
        if provider.lower() == 'ancestry':
            line = fin.readline()
        while line:
            rsid, snp = reader(line)
            genome[rsid] = snp
            line = fin.readline()
    return genome


def ttandme_reader(line):
    rsid, chromosome, position, genotype = line.strip().split('\t')
    snp = SNP(chromosome=chromosome,
              position=position,
              genotype=Genotype(genotype))
    return rsid, snp


def ancestry_reader(line):
    rsid, chromosome, position, allele1, allele2 = line.strip().split('\t')
    genotype = allele1 + allele2
    snp = SNP(chromosome=chromosome,
              position=position,
              genotype=Genotype(genotype))
    return rsid, snp



# coding=utf-8
"""Genotype"""


class Genotype:
    """
    Genotype

    Parameters
    ----------
    genotype : str
        genotype
    """
    def __init__(self, genotype):
        self._genotype = genotype

    def __repr__(self):
        return '<Genotype: {!r}>'.format(str(self))

    def __str__(self):
        return self._genotype

    def __eq__(self, other):
        return self._genotype == other




# THIS FILE IS GENERATED FROM SCIPY SETUP.PY
short_version = '0.1.5'
version = '0.1.5'
full_version = '0.1.5.dev1558626070'
dev_version = '1558626070'
release = False
if not release:
    version = full_version



# coding=utf-8
"""SNP"""


class SNP:
    """
    SNP
    
    Parameters
    ----------
    chromosome : str or int
        chromosome
    position : str or int
        position
    genotype : Genotype
        genotype
    """
    def __init__(self, chromosome, position, genotype):
        self.chromosome = str(chromosome)
        self.position = int(position)
        self.genotype = genotype

    def __repr__(self):
        return '<SNP: chromosome={!r} position={!r} genotype={!r}>'.format(
            self.chromosome,
            self.position,
            self.genotype)

    def __eq__(self, other):
        return self.genotype == other.genotype and \
               self.position == other.position and \
               self.genotype == other.genotype
